@@ -1,6 +1,6 @@
 package Date::Julian::Simple;
 
-$Date::Julian::Simple::VERSION   = '0.14';
+$Date::Julian::Simple::VERSION   = '0.15';
 $Date::Julian::Simple::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Date::Julian::Simple - Represents Julian date.
 
 =head1 VERSION
 
-Version 0.14
+Version 0.15
 
 =cut
 
@@ -244,7 +244,7 @@ Returns 0 or 1 if the given Julian year C<$year> is a leap year or not.
 sub is_leap_year {
     my ($self, $year) = @_;
 
-    return (($year % 4) == (($year > 0) ? 0 : 3));
+    return (($year % 4) == (($year > 0) ? 0 : 3)) || 0;
 }
 
 sub days_in_year {
